# NewsFrames

A single-label classifier for universal framing dimensions in news articles on political
topics.

## Setup

Create python environment, for example with conda:

```bash
conda create --yes -n NewsFrames python=3.9
conda activate NewsFrames
```

Install:

```bash
pip install NewsFrames
```

## Usage

```python

```
